@@ -8,6 +8,8 @@ fn main() {
     println!("cargo:rerun-if-changed=wrapper.h");
     println!("cargo:rerun-if-changed=patch/config.h");
 
+    let linuxcnc_root = env::var("LINUXCNC_SRC").expect("LINUXCNC_SRC env var must be set and pointing to the root of the LinuxCNC source Git repository");
+
     // fs::copy("patch/config.h", "linuxcnc-src/src/config.h")
     //     .expect("Failed to copy config patch file");
 
@@ -18,8 +20,9 @@ fn main() {
         // The input header we would like to generate
         // bindings for.
         .header("wrapper.h")
-        .clang_arg("-Ilinuxcnc-src/src/hal")
-        .clang_arg("-Ilinuxcnc-src/src/rtapi")
+        .clang_arg(&format!("-I{}", linuxcnc_root))
+        .clang_arg(&format!("-I{}/src/hal", linuxcnc_root))
+        .clang_arg(&format!("-I{}/src/rtapi", linuxcnc_root))
         // Tell LinuxCNC build to run in non-realtime mode
         // See line ~114 in linuxcnc-src/src/hal/hal.h
         .clang_arg("-DULAPI")
@@ -39,14 +42,14 @@ fn main() {
 
     cc::Build::new()
         .files(&[
-            "linuxcnc-src/src/hal/hal_lib.c",
-            "linuxcnc-src/src/rtapi/uspace_ulapi.c",
+            &format!("{}/src/hal/hal_lib.c", linuxcnc_root),
+            &format!("{}/src/rtapi/uspace_ulapi.c", linuxcnc_root),
         ])
         .define("ULAPI", None)
         .include("patch")
-        .include("linuxcnc-src/src/hal")
-        .include("linuxcnc-src/src/rtapi")
-        .include("linuxcnc-src/src")
+        .include(&format!("{}/src/hal", linuxcnc_root))
+        .include(&format!("{}/src/rtapi", linuxcnc_root))
+        .include(&format!("{}/src", linuxcnc_root))
         .warnings(false)
         .compile("linuxcnchal");
 }
